package com.mortals.xhx.module.proposal.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.RepeatSubmit;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.IBaseEnum;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.IUser;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.code.ReplyStatusEnum;
import com.mortals.xhx.common.code.SendModeEnum;
import com.mortals.xhx.common.code.SendStatusEnum;
import com.mortals.xhx.common.key.Constant;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.service.CustomerService;
import com.mortals.xhx.module.help.model.HelpEvaluateEntity;
import com.mortals.xhx.module.proposal.model.ProposalEntity;
import com.mortals.xhx.module.proposal.service.ProposalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;
/**
*
* 客户建议信息
*
* @author zxfei
* @date 2022-06-28
*/
@RestController
@RequestMapping("proposal")
public class ProposalController extends BaseCRUDJsonBodyMappingController<ProposalService,ProposalEntity,Long> {

    @Autowired
    private CustomerService customerService;

    public ProposalController(){
        super.setModuleDesc( "客户建议信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "replyStatus", IBaseEnum.getEnumMap(ReplyStatusEnum.class));
        this.addDict(model, "sendMode", IBaseEnum.getEnumMap(SendModeEnum.class));
        this.addDict(model, "sendStatus", IBaseEnum.getEnumMap(SendStatusEnum.class));
        super.init(model, context);
    }

    @Override
    protected void saveBefore(ProposalEntity entity, Map<String, Object> model, Context context) throws AppException {
        if(this.getCurUser()!=null&&this.getCurUser().getUserType()== Constant.CUSTOMER_USER){
            CustomerEntity customerEntity = customerService.get(this.getCurUser().getId());
            entity.setCustomerId(this.getCurUser().getId());
            entity.setCustName(customerEntity.getCustName());
            entity.setContactTelphone(customerEntity.getContactTelphone());
        }
        if(entity.newEntity()){
            entity.setReplyStatus(ReplyStatusEnum.UN_REPLY.getValue());
        }
    }

    @Override
    protected void doListBefore(ProposalEntity query, Map<String, Object> model, Context context) throws AppException {
        Map<String,String> orderCols = new HashMap<>();
        orderCols.put("createTime","DESC");
        query.setOrderCols(orderCols);
    }

    @PostMapping({"reply"})
    @RepeatSubmit
    public String reply(@RequestBody ProposalEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        int code = 1;
        String busiDesc = "保存" + this.getModuleDesc();


        try {
            if(entity.getId()==null){
                throw new AppException("建议id不能为空");
            }
            IUser user;
            busiDesc = "修改" + this.getModuleDesc();
            entity.setUpdateTime(new Date());
            user = this.getCurUser();
            if (user != null) {
                entity.setUpdateUserId(user.getId());
                entity.setUpdateUser(user.getLoginName());
                entity.setUpdateUserName(user.getRealName());
                entity.setUpdateUserDeptId(user.getDeptId());
                entity.setUpdateUserDeptName(user.getDeptName());
            }
            entity.setReplyTime(new Date());
            entity.setReplyStatus(ReplyStatusEnum.REPLY.getValue());
            this.service.update(entity, context);

            model.put("id", entity.getId());
            code = this.saveAfter(entity, model, context);
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            this.init(model, context);
            code = this.saveException(entity, model, context, var7);
        }

        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @PostMapping({"save"})
    @UnAuth
    public String save(@RequestBody ProposalEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "保存" + this.getModuleDesc();

        int code=1;
        try {
            this.saveBefore(entity, model, context);
            IUser user;
            if (entity.newEntity()) {
                busiDesc = "新增" + this.getModuleDesc();
                entity.setCreateTime(new Date());
                entity.setUpdateTime(entity.getCreateTime());
                user = this.getCurUser();
                if (user != null) {
                    entity.setCreateUserId(user.getId());
                    entity.setCreateUser(user.getLoginName());
                    entity.setCreateUserName(user.getRealName());
                    entity.setCreateUserDeptId(user.getDeptId());
                    entity.setCreateUserDeptName(user.getDeptName());
                    entity.setUpdateUserId(user.getId());
                    entity.setUpdateUser(user.getLoginName());
                    entity.setUpdateUserName(user.getRealName());
                    entity.setUpdateUserDeptId(user.getDeptId());
                    entity.setUpdateUserDeptName(user.getDeptName());
                }

                this.service.save(entity, context);
            } else {
                busiDesc = "修改" + this.getModuleDesc();
                entity.setUpdateTime(new Date());
                user = this.getCurUser();
                if (user != null) {
                    entity.setUpdateUserId(user.getId());
                    entity.setUpdateUser(user.getLoginName());
                    entity.setUpdateUserName(user.getRealName());
                    entity.setUpdateUserDeptId(user.getDeptId());
                    entity.setUpdateUserDeptName(user.getDeptName());
                }

                this.service.update(entity, context);
            }

            model.put("id", entity.getId());
            code = this.saveAfter(entity, model, context);
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            this.init(model, context);
            code = this.saveException(entity, model, context, var7);
        }

        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }
}